<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Account</source>
        <translation>Conto</translation>
    </message>
    <message>
        <source>File transfers and voice chats</source>
        <translation>File trasferimento e Chat a voce</translation>
    </message>
    <message>
        <source>Voice chats</source>
        <translation>Chat a voce</translation>
    </message>
    <message>
        <source>Faster compression algorithm (degrades quality)</source>
        <translation>Compressione veloce (degrada qualità)</translation>
    </message>
    <message>
        <source>Cut-off optimization (faster but degrades quality)</source>
        <translation>Ottimizzazione Cut-off (più veloce ma degrada qualità)</translation>
    </message>
    <message>
        <source>Test GSM Encoding</source>
        <translation>Test Codifica GSM</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Voice chat</source>
        <translation>Chat a voce</translation>
    </message>
    <message>
        <source>Sending files and voice chats</source>
        <translation>Manda un file e Chat a voce</translation>
    </message>
</context>
<context>
    <name>VoiceChatDialog</name>
    <message>
        <source>Voice chat</source>
        <translation>Chat a voce</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
</context>
<context>
    <name>VoiceManager</name>
    <message>
        <source>Voice chat</source>
        <translation>Chat a voce</translation>
    </message>
    <message>
        <source>User %1 wants to talk with you. Do you accept it?</source>
        <translation>Contatto %1 deisdera parlare con te. Accetti ?</translation>
    </message>
    <message>
        <source>Opening DSP Encoder failed.</source>
        <translation>Apertura Encoder DSP fallita.</translation>
    </message>
    <message>
        <source>Opening sound device failed.</source>
        <translation>Apertura dispositivo audio fallita.</translation>
    </message>
    <message>
        <source>Testing GSM Encoding. Please talk now (3 seconds).</source>
        <translation>Test codifica GSM. Prego di parlare per 3 secondi.</translation>
    </message>
    <message>
        <source>You should hear your recorded sample now.</source>
        <translation>Audio registrato dovrebbe farsi sentire.</translation>
    </message>
</context>
</TS>
